@@ -39,7 +39,8 @@ def create_shapley_schema(
     logging.info("Shapley - Creating schema")
     fname = "schema.json"
     fpath = os.path.join(folder, fname)
-    example = x.head(1)
+    example = x[profile_columns].head(1)
+
     data = create_explainer_schema(
         explainer_schema_example=example,
         explainer=explainer,
